@@ -1,8 +1,14 @@
-from cors import preflight
-
 def not_allowed():
     return "", 405
 
+def preflight():
+    return "", 204, {
+        "Access-Control-Allow-Origin": "*",
+        "Access-Control-Allow-Methods": "GET",
+        "Access-Control-Allow-Headers": "Content-Type",
+        "Access-Control-Max-Age": "3600"
+    }
+
 class Endpoint:
     http_verbs = ["get", "head", "post", "put", "delete", "connect", "options",
                   "trace", "patch"]
